deriva.transfer.download package
================================

Subpackages
-----------

.. toctree::

    deriva.transfer.download.processors

Submodules
----------

deriva.transfer.download.deriva\_download module
------------------------------------------------

.. automodule:: deriva.transfer.download.deriva_download
    :members:
    :undoc-members:
    :show-inheritance:

deriva.transfer.download.deriva\_download\_cli module
-----------------------------------------------------

.. automodule:: deriva.transfer.download.deriva_download_cli
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: deriva.transfer.download
    :members:
    :undoc-members:
    :show-inheritance:
